@@ -1,4 +1,4 @@
-from src.tws_integrated_functions.appConnectionTws import ConnectionTwsApi
+from tws_integrated_functions.appConnectionTws import ConnectionTwsApi
 from ibapi.utils import iswrapper
 
 
