@@ -1,7 +1,7 @@
 """
 Class to be used when we want to access details for a contract
 """
-from src.tws_integrated_functions.appConnectionTws import ConnectionTwsApi
+from tws_integrated_functions.appConnectionTws import ConnectionTwsApi
 from ibapi.utils import iswrapper
 
 
